@@ -76,10 +76,7 @@ Lukk
 >>> print n.get_octave_notename()
 d'
 """
-if __name__ == "__main__":
-    import testsetup
 
-import unittest
 import random
 import _exceptions
 
@@ -300,7 +297,12 @@ class MusicalPitch:
             r.m_accidental_i = r.m_accidental_i + (i.get_intvalue() - _diff)
             # to avoid notenames like ciscisciscis :
             if r.m_accidental_i > 2:
-                r.m_accidental_i = r.m_accidental_i - 2
+                #                     c  d  f  g  a
+                if r.m_notename_i in (0, 1, 3, 4, 5):
+                    r.m_accidental_i -= 2
+                else:
+                    assert r.m_notename_i in (2, 6), r.m_notename_i
+                    r.m_accidental_i -= 1
                 r.m_notename_i = r.m_notename_i + 1
                 if r.m_notename_i == 7:
                     r.m_notename_i = 0
@@ -377,7 +379,7 @@ class MusicalPitch:
         if self.m_octave_i > 0:
             oct = "'" * self.m_octave_i
         elif self.m_octave_i < 0:
-            oct= "," * (-self.m_octave_i)
+            oct = "," * (-self.m_octave_i)
         else:
             oct = ""
         if self.m_octave_i < 0:
@@ -405,36 +407,3 @@ class MusicalPitch:
             print "Bad translation of notenameformat string"
             return "%(notename)s%(oct)s" % D
 
-class TestMusicalPitch(unittest.TestCase):
-    def test_normalize_double_accidental(self):
-        for a, b in (("c", "c"),
-                     ("cisis", "d"),
-                     ("disis", "e"),
-                     ("eisis", "fis"),
-                     ("fisis", "g"),
-                     ("gisis", "a"),
-                     ("aisis", "b"),
-                     ("bisis", "cis'"),
-                     ("ceses", "bes,"),
-                     ("deses", "c"),
-                     ("eses", "d"),
-                     ("feses", "ees"),
-                     ("geses", "f"),
-                     ("ases", "g"),
-                     ("beses", "a"),
-                     ):
-            n = MusicalPitch.new_from_notename(a)
-            n.normalize_double_accidental()
-            self.assertEquals(n.get_octave_notename(), b)
-
-def _test():
-    import doctest
-    import musicalpitch
-    return doctest.testmod(musicalpitch)
-
-def _test2():
-    unittest.main()
-
-if __name__ == "__main__":
-    _test()
-    _test2()
