@@ -344,8 +344,8 @@ class Track:
         for track in [self, B]:
             pos = Rat(0, 1)
             for event in track.m_v:
-                if event[0] == Track.NOTELEN_TIME:
-                    pos = pos + event[1]
+                if isinstance(event, Delay):
+                    pos = pos + event.m_duration
                 else:
                     if pos not in D:
                         D[pos] = []
@@ -356,7 +356,7 @@ class Track:
         for x in range(len(kv)-1):
             for event in D[kv[x]]:
                 self.m_v.append(event)
-            self.m_v.append((Track.NOTELEN_TIME, kv[x+1]-kv[x]))
+            self.m_v.append(Delay(kv[x+1]-kv[x]))
         for event in D[kv[-1]]:
             self.m_v.append(event)
     def replace_note(self, old, new):
