@@ -17,7 +17,6 @@
 
 import sys, os, tempfile, signal
 import textwrap
-from synth_common import SynthCommon
 from mpd.track import MidiEventStream
 
 def ms_win_kill(pid):
@@ -25,10 +24,9 @@ def ms_win_kill(pid):
     handle = win32api.OpenProcess(1, 0, pid)
     return (0 != win32api.TerminateProcess(handle, 0))
 
-class MidiFileSynth(SynthCommon):
+class MidiFileSynth(object):
     NUM_CHANNELS = 16
     def __init__(self, cmd, verbose_init):
-        SynthCommon.__init__(self)
         self.m_type_major = "Midifile"
         self.m_cmd = cmd
         self.m_tmpfilename = tempfile.mkstemp(".mid")[1]
