@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 import oss_common
 import solfege_c_midi
-from track import MidiEventStream
+from mpd.track import MidiEventStream
 
 class OSSSequencer2Synth(oss_common.AbstractSynth):
     def __init__(self, device, devnum, verbose_init):
@@ -73,13 +73,14 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
 
 def test():
     synth = OSSSequencer2Synth("/dev/sequencer2", 1, None)
-    import sys, track
-    from rat import Rat
+    import sys
+    from mpd.track import Track
+    from mpd.rat import Rat
     sys.path.insert(0, ".")
     import src.i18n
     src.i18n.setup(".")
     src.i18n.setup(".")
-    t1 = track.Track()
+    t1 = Track()
     t1.start_note(70, 127)
     t1.notelen_time(Rat(1, 4))
     t1.stop_note(70, 127)
@@ -90,7 +91,7 @@ def test():
     t1.start_note(71, 126)
     t1.notelen_time(Rat(1, 16))
     t1.stop_note(71, 126)
-    t2 = track.Track()
+    t2 = Track()
     t2.start_note(80, 127)
     t2.notelen_time(Rat(1, 2))
     t2.stop_note(80, 127)
