@@ -24,8 +24,6 @@ import mpd.musicdisplayer
 import const
 import abstract
 import lessonfile
-import cfg
-import dataparser
 import soundcard
 
 class Teacher(abstract.Teacher):
