@@ -157,6 +157,39 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_mail_program.connect('changed', lambda w: self.set_string('config/mua', self.g_mail_program.get_text()))
         box = gu.hig_label_widget(_("_Mail program:"), self.g_mail_program, sizegroup)
         category_vbox.pack_start(box)
+        # midi_to_wav
+        liststore = gtk.ListStore(gobject.TYPE_STRING)
+        liststore.append(("/usr/bin/timidity -Ow %(in)s -o %(out)s",))
+        self.g_wav_convertor = gtk.ComboBoxEntry(liststore)
+        self.g_wav_convertor.child.set_text(
+            self.get_string("app/midi_to_wav_cmd"))
+        self.g_wav_convertor.connect('changed', 
+            lambda w: self.set_string('app/midi_to_wav_cmd', w.child.get_text()))
+        category_vbox.pack_start(
+            gu.hig_label_widget(_("MIDI to WAV convertor:"),
+            self.g_wav_convertor, sizegroup))
+        # wav_to_mp3
+        liststore = gtk.ListStore(gobject.TYPE_STRING)
+        liststore.append(("/usr/bin/lame %(in)s %(out)s",))
+        self.g_mp3_convertor = gtk.ComboBoxEntry(liststore)
+        self.g_mp3_convertor.child.set_text(
+            self.get_string("app/wav_to_mp3_cmd"))
+        self.g_mp3_convertor.connect('changed', 
+            lambda w: self.set_string('app/wav_to_mp3_cmd', w.child.get_text()))
+        category_vbox.pack_start(
+            gu.hig_label_widget(_("WAV to MP3 convertor:"),
+            self.g_mp3_convertor, sizegroup))
+        # wav_to_ogg
+        liststore = gtk.ListStore(gobject.TYPE_STRING)
+        liststore.append(("/usr/bin/oggenc %(in)s",))
+        self.g_ogg_convertor = gtk.ComboBoxEntry(liststore)
+        self.g_ogg_convertor.child.set_text(
+            self.get_string("app/wav_to_ogg_cmd"))
+        self.g_ogg_convertor.connect('changed', 
+            lambda w: self.set_string('app/wav_to_ogg_cmd', w.child.get_text()))
+        category_vbox.pack_start(
+            gu.hig_label_widget(_("WAV to OGG convertor:"),
+            self.g_ogg_convertor, sizegroup))
 
         box, category_vbox = gu.hig_category_vbox(_("Misc"))
         page_vbox.pack_start(box, False)
@@ -189,9 +222,9 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_language.connect_after('changed', f)
         hbox.pack_start(self.g_language, False)
         category_vbox.pack_start(hbox)
-	l = gtk.Label(_("You have to restart the program for the language change to take effect."))
-	l.set_alignment(0.0, 0.5)
-	category_vbox.pack_start(l)
+        l = gtk.Label(_("You have to restart the program for the language change to take effect."))
+        l.set_alignment(0.0, 0.5)
+        category_vbox.pack_start(l)
         ############
         # Practise #
         ############
