@@ -145,7 +145,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_guess_answer.set_sensitive(False)
             self.g_play_tonic.set_sensitive(False)
             if not self.standard_exception_handler(e, __file__):
-                raise e
+                raise
         else:
             self.g_new.set_sensitive(
                 not self.get_bool('config/picky_on_new_question'))
