@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -360,9 +360,9 @@ class HarmonicProgressionLabel(gtk.HBox):
             self.pack_start(gtk.HBox())
         self.show_all()
     def get_next_token(self):
-        m_re1 = re.compile("([^\(]+)")
-        m_re2 = re.compile("\((\w*),\s*(\w*)\)")
-        m_re3 = re.compile("\((\w*)\)")
+        m_re1 = re.compile("([^\(]+)", re.UNICODE)
+        m_re2 = re.compile("\((\w*),\s*(\w*)\)", re.UNICODE)
+        m_re3 = re.compile("\((\w*)\)", re.UNICODE)
         m1 = m_re1.match(self.m_str)
         m2 = m_re2.match(self.m_str)
         m3 = m_re3.match(self.m_str)
@@ -409,12 +409,14 @@ def dialog_yesno(text, parent=None):
     m.destroy()
     return ret == gtk.RESPONSE_YES
 
-def dialog_ok(text, parent=None):
+def dialog_ok(text, parent=None, secondary_text=None):
     """"
     Return the gtk.RESPONSE_XXXX returned by .run()
     """
     m = gtk.MessageDialog(parent, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
             gtk.BUTTONS_OK, text)
+    if secondary_text:
+        m.format_secondary_text(secondary_text)
     ret = m.run()
     m.destroy()
     return ret
