@@ -797,7 +797,8 @@ class Window(gtk.Window):
         hbox.set_spacing(12)
         vbox.pack_start(hbox, False)
         self.g_heading.set_use_markup(True)
-        self.g_filename_description = gtk.Label(_("Do not enter any directory names, only the filename."))
+        donot_str = _("Do not enter any directory names, only the filename.")
+        self.g_filename_description = gtk.Label(donot_str)
         self.g_message = gtk.Label(_("File name:"))
         self.g_entry = gtk.Entry()
         self.g_entry.set_activates_default(True)
@@ -810,7 +811,7 @@ class Window(gtk.Window):
             if ret == gtk.RESPONSE_OK:
                 path, filename = os.path.split(self.g_entry.get_text())
                 if path or (not filename):
-                    self.g_filename_description.set_text(_("Enter a file name with no directory."))
+                    self.g_filename_description.set_text(donot_str)
                     self.g_filename_description.show()
                 elif os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename)):
                     self.g_filename_description.set_text(_("The file already exists."))
