@@ -1205,7 +1205,7 @@ def parse_lesson_file_header(filename):
     it provides a 22x speedup, and that was necessary when we got
     many lesson files.
     """
-    r = re.compile("\\header\s{.*?}", re.MULTILINE|re.DOTALL)
+    r = re.compile("\\header\s*{.*?}", re.MULTILINE|re.DOTALL)
     s = open(filename, 'rU').read()
     m = r.search(s)
     p = dataparser.Dataparser(predef, lessonfile_functions)
