@@ -458,10 +458,10 @@ class TrainingSetDialog(gtk.Window):
                 dialog.destroy()
                 return
             if os.listdir(dialog.get_filename()):
-                msg = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
+                msg_dlg = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
                     gtk.MESSAGE_INFO, gtk.BUTTONS_OK, msg)
-                msg.run()
-                msg.destroy()
+                msg_dlg.run()
+                msg_dlg.destroy()
             else:
                 break
         export_to = dialog.get_filename()
