@@ -21,9 +21,9 @@ img_str = """%i:<inlinemediaobject>
     </inlinemediaobject>"""
 f = open("help/C/rhythmtable.xml", "w")
 print >> f, "<para>"
-for i, r in enumerate(src.rhythm.RHYTHMS):
+for i, r in enumerate(src.abstract.RhythmAddOnClass.RHYTHMS):
     print >> f, img_str % (i, r.replace(" ", ""), r),
-    if i != len(src.rhythm.RHYTHMS) - 1:
+    if i != len(src.abstract.RhythmAddOnClass.RHYTHMS) - 1:
         print >> f, ", "
 print >> f, "</para>"
 f.close()
